@@ -423,9 +423,8 @@ class Step:
             self.template = new_template
 
         if self.parallelism is not None:
-            assert hasattr(self.template, "slices") and self.template.slices \
-                is not None, "Only sliced step can be assigned with "\
-                "parallelism"
+            assert self.with_param is not None or self.with_sequence is not \
+                None, "Only parallel step can be assigned with parallelism"
             from .dag import DAG
             from .steps import Steps
             from .task import Task
@@ -462,13 +461,15 @@ class Step:
                     del self.inputs.artifacts[name]
                 else:
                     step.set_artifacts({name: steps.inputs.artifacts[name]})
-            for name in list(step.prepare_step.inputs.parameters.keys()):
-                step.prepare_step.set_parameters({
-                    name: steps.inputs.parameters[name]})
-            for name, art in list(self.prepare_step.inputs.artifacts.items()):
-                if not isinstance(art.source, S3Artifact):
-                    step.prepare_step.set_artifacts({
-                        name: steps.inputs.artifacts[name]})
+            if self.prepare_step is not None:
+                for name in list(self.prepare_step.inputs.parameters.keys()):
+                    step.prepare_step.set_parameters({
+                        name: steps.inputs.parameters[name]})
+                for name, art in list(
+                        self.prepare_step.inputs.artifacts.items()):
+                    if not isinstance(art.source, S3Artifact):
+                        step.prepare_step.set_artifacts({
+                            name: steps.inputs.artifacts[name]})
             steps.add(step)
             for name, par in list(self.outputs.parameters.items()):
                 if not par.save_as_artifact:
@@ -477,8 +478,8 @@ class Step:
                 else:
                     del steps.outputs.parameters[name]
                     del self.outputs.parameters[name]
-            for name in list(self.outputs.artifacts.keys()):
-                if name in self.template.slices.output_artifact:
+            for name, art in list(self.outputs.artifacts.items()):
+                if art.redirect is not None:
                     steps.outputs.artifacts[name]._from = \
                         step.outputs.artifacts[name]
                 else:
